package me.km.commands;

import me.kt.api.GlobalText;
import me.kt.api.Module;
import me.kt.api.ModuleCommand;
import me.kt.api.SimpleTabCompleter;
import java.util.Arrays;
import org.bukkit.Material;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.PotionMeta;
import org.bukkit.potion.PotionEffect;
import org.bukkit.potion.PotionEffectType;

public class CommandPotion extends ModuleCommand
{
    public CommandPotion(Module m) 
    {
        super("potion", m);
        this.setDescription("Erzeugt Custom-Potions");
        this.setUsage("/potion [clear] [effect] [duration] [amplifier]");
        this.setPermission("kt.potion");
        
        m.registerTabCompleter("potion", new SimpleTabCompleter(Arrays.asList(new String[]{
            "ABSORPTION", "BLINDNESS", "CONFUSION", "DAMAGE_RESISTANCE", "FAST_DIGGING",
            "FIRE_RESISTANCE", "GLOWING", "HARM", "HEAL", "HEALTH_BOOST", "HUNGER",
            "INCREASE_DAMAGE", "INVISIBILITY", "JUMP", "LEVITATION", "LUCK", "POISON",
            "REGENERATION", "SATURATION", "SLOW", "SLOW_DIGGING", "SPEED", "UNLUCK",
            "WATER_BREATHING", "WEAKNESS", "WITHER"}), 1));
    }

    @Override
    public boolean execute(CommandSender cs, String string, String[] arg) 
    {
        if(!(cs instanceof Player))
        {
            this.getModule().send(cs, GlobalText.onlyPlayer());
            return true;
        }
        Player p = (Player) cs;
        ItemStack hand = p.getInventory().getItemInMainHand();
        if(hand.getType() != Material.SPLASH_POTION &&
           hand.getType() != Material.POTION &&
           hand.getType() != Material.LINGERING_POTION)
        {
            this.getModule().send(cs, "Du musst einen Trank in der Hand halten.");
            return true;
        }
        if(arg.length < 1)
        {
            return false;
        }
        PotionMeta meta = (PotionMeta) hand.getItemMeta();
        if(arg[0].equals("clear"))
        {
            meta.clearCustomEffects();
            hand.setItemMeta(meta);
            p.getInventory().setItemInMainHand(hand);
            this.getModule().send(cs, "Alle Custom-Effekte wurden entfernt");
            return true;
        }
        try
        {
            meta.addCustomEffect(new PotionEffect(PotionEffectType.getByName(arg[0].toUpperCase()), Integer.parseInt(arg[1]), Integer.parseInt(arg[2])), true);
            this.getModule().send(cs, "Der Effekt wurde hinzugefügt.");
        }
        catch(NumberFormatException ex)
        {
            this.getModule().send(cs, GlobalText.noIntegerNumber());
            return true;
        }
        catch(IllegalArgumentException ex)
        {
            this.getModule().send(cs, "Der gegebene Potion-Effect existiert nicht.");
            return true;
        }
        catch(ArrayIndexOutOfBoundsException ex)
        {
            return false;
        }
        hand.setItemMeta(meta);
        p.getInventory().setItemInMainHand(hand);
        return true;
    }
}
